PackxelInitializer

Struct PackxelInitializer 

pub struct PackxelInitializer {
    pub name: String,
    pub version: String,
}

Fields

name: String

name of the package

creates folder of same name

version: String

version of the package

to be used in manifest inside config folder

Implementations

Source

impl PackxelInitializer

Initializer is a struct that is used to initialize the config and log directories.

This can further be used to setup logging.

use packxel_utils::initializer::PackxelInitializer;
// creates the config and log directories.
let version = env!("CARGO_PKG_VERSION");
let initializer = PackxelInitializer::init("packxel", version);
pub fn get_config_dir(&self) -> PathBuf

Returns the config directory of the user or creates it if it doesn’t exist.

pub fn get_log_dir(&self) -> PathBuf

Returns the log directory of the user or creates it if it doesn’t exist.

pub fn get_log_file(&self) -> PathBuf

This does not create the file. Only returns the path to the log file.

use packxel_utils::initializer::PackxelInitializer;
let initializer = PackxelInitializer::init("testing", "0.0.1");
let log_file_path = initializer.get_log_file();
pub fn init<S: Into<String>, R: Into<String>>(name: S, version: R) -> Self

Initializes the Initializer struct.

This should be called before logging or other utils of packxel program are initialized.